@@ -46,16 +46,13 @@ sub detect {
         return $self;
     }
 
-    my $name = Mojo::Script->class_to_file($class);
-
     # Try to find home from lib directory
     if ($class) {
 
         # Load?
         my $file = Mojo::Script->class_to_path($class);
         unless ($INC{$file}) {
-            my $e = Mojo::Loader->new->load($class);
-            die $e if $e;
+            if (my $e = Mojo::Loader->load($class)) { die $e if ref $e }
         }
 
         # Detect
@@ -85,7 +82,7 @@ sub lib_dir {
     return $path if -d $path;
 
     # No lib directory
-    return undef;
+    return;
 }
 
 sub parse {
@@ -115,27 +112,21 @@ Mojo::Home - Detect And Access The Project Root Directory In Mojo
 =head1 DESCRIPTION
 
 L<Mojo::Home> is a container for home directories.
-Functionality includes locating the home directory and portable path handling.
 
 =head1 ATTRIBUTES
 
+L<Mojo::Home> implements the following attributes.
+
 =head2 C<app_class>
 
     my $class = $home->app_class;
     $home     = $home->app_class('Foo::Bar');
 
-Returns the Mojo applications class name if called without arguments.
-Returns the invocant if called with arguments.
-
 =head2 C<parts>
 
     my $parts = $home->parts;
     $home     = $home->parts([qw/foo bar baz/]);
 
-Returns an arrayref containing the parts of the projects root directory if
-called without arguments.
-Returns the invocant if called with arguments.
-
 =head1 METHODS
 
 L<Mojo::Home> inherits all methods from L<Mojo::Base> and implements the
@@ -146,50 +137,30 @@ following new ones.
     my $home = Mojo::Home->new;
     my $home = Mojo::Home->new('/foo/bar/baz');
 
-Returns a new L<Mojo::Home> object, used to find the root directory of the
-project.
-
 =head2 C<detect>
 
     $home = $home->detect;
     $home = $home->detect('My::App');
 
-Returns the invocant and detects the path to the root of the Mojo project.
-C<$ENV{MOJO_HOME}> is used as the location if available.
-Autodetection based on the class name is used as a fallback.
-
 =head2 C<lib_dir>
 
     my $path = $home->lib_dir;
 
-Returns the path to the C<lib> directory of the project if it exists, or
-undef otherwise.
-
 =head2 C<parse>
 
     $home = $home->parse('/foo/bar');
 
-Returns the invocant and splits the given path into C<parts>.
-
 =head2 C<rel_dir>
 
     my $path = $home->rel_dir('foo/bar');
 
-Returns an absolute directory path based on the projects root directory.
-Note that the UNIX style C</> is used as separator on all platforms.
-
 =head2 C<rel_file>
 
     my $path = $home->rel_file('foo/bar.html');
 
-Returns an absolute file path based on the projects root directory.
-Note that the UNIX style C</> is used as separator on all platforms.
-
 =head2 C<to_string>
 
     my $string = $home->to_string;
     my $string = "$home";
 
-Return the path to projects root directory.
-
 =cut
