@@ -83,7 +83,7 @@ WriteMakefile(
     NAME         => '<%= $class %>',
     VERSION_FROM => 'lib/<%= $path %>',
     AUTHOR       => 'A Good Programmer <nospam@cpan.org>',
-    EXE_FILES => ['bin/<%= $name %>'],
+    EXE_FILES => ['script/<%= $name %>'],
     PREREQ_PM => { 'Mojo' => '0.9003' },
     test => {TESTS => 't/*.t t/*/*.t t/*/*/*.t'}
 );
