@@ -8,7 +8,7 @@ use warnings;
 use base 'Mojo::Server';
 use bytes;
 
-use IO::Select;
+use IO::Poll 'POLLIN';
 
 # Roles
 my @ROLES = qw/RESPONDER  AUTHORIZER FILTER/;
@@ -56,7 +56,8 @@ sub accept_connection {
     # Accept
     my $connection = undef;
     unless (accept $connection, $self->{_listen}) {
-        $self->{error} = "Can't accept connection: $!";
+        $self->app->log->error("Can't accept FastCGI connection: $!");
+        return;
     }
 
     # Blocking sucks
@@ -66,11 +67,11 @@ sub accept_connection {
 
 sub read_record {
     my ($self, $connection) = @_;
-    return undef unless $connection;
+    return unless $connection;
 
     # Header
     my $header = $self->_read_chunk($connection, 8);
-    return undef unless $header;
+    return unless $header;
     my ($version, $type, $id, $clen, $plen) = unpack 'CCnnC', $header;
 
     # Body
@@ -96,8 +97,9 @@ sub read_request {
     # Type
     my ($type, $id, $body) = $self->read_record($connection);
     unless ($type && $type eq 'BEGIN_REQUEST') {
-        $self->{error} = "First record wasn't a begin request";
-        return undef;
+        $self->app->log->error(
+            "First FastCGI record wasn't a begin request.");
+        return;
     }
     $ENV{FCGI_ID} = $tx->{fcgi_id} = $id;
 
@@ -156,13 +158,13 @@ sub read_request {
 
 sub role_name {
     my ($self, $role) = @_;
-    return undef unless $role;
+    return unless $role;
     return $ROLES[$role - 1];
 }
 
 sub role_number {
     my ($self, $role) = @_;
-    return undef unless $role;
+    return unless $role;
     return $ROLE_NUMBERS{uc $role};
 }
 
@@ -176,7 +178,10 @@ sub run {
         my $tx = $self->read_request($connection);
 
         # Error
-        next unless $tx;
+        unless ($tx) {
+            $self->app->log->error("No transaction for FastCGI request.");
+            next;
+        }
 
         # Handle
         $self->handler_cb->($self, $tx);
@@ -187,13 +192,13 @@ sub run {
 
 sub type_name {
     my ($self, $type) = @_;
-    return undef unless $type;
+    return unless $type;
     return $TYPES[$type - 1];
 }
 
 sub type_number {
     my ($self, $type) = @_;
-    return undef unless $type;
+    return unless $type;
     return $TYPE_NUMBERS{uc $type};
 }
 
@@ -201,14 +206,14 @@ sub write_records {
     my ($self, $connection, $type, $id, $body) = @_;
 
     # Required
-    return undef unless defined $connection && defined $type && defined $id;
+    return unless defined $connection && defined $type && defined $id;
 
     # Defaults
     $body ||= '';
     my $length = length $body;
 
     # Write records
-    my $empty = 1 unless $body;
+    my $empty = $body ? 0 : 1;
     my $offset = 0;
     while (($length > 0) || $empty) {
 
@@ -225,6 +230,7 @@ sub write_records {
         my $woffset = 0;
         while ($woffset < length $record) {
             my $written = $connection->syswrite($record, undef, $woffset);
+            return unless defined $written;
             $woffset += $written;
         }
 
@@ -233,6 +239,8 @@ sub write_records {
 
         last if $empty;
     }
+
+    return 1;
 }
 
 sub write_response {
@@ -261,7 +269,9 @@ sub write_response {
 
         # Headers
         $offset += length $chunk;
-        $self->write_records($connection, 'STDOUT', $tx->{fcgi_id}, $chunk);
+        return
+          unless $self->write_records($connection, 'STDOUT', $tx->{fcgi_id},
+            $chunk);
     }
 
     # Body
@@ -280,12 +290,17 @@ sub write_response {
 
         # Content
         $offset += length $chunk;
-        $self->write_records($connection, 'STDOUT', $tx->{fcgi_id}, $chunk);
+        return
+          unless $self->write_records($connection, 'STDOUT', $tx->{fcgi_id},
+            $chunk);
     }
 
     # The end
-    $self->write_records($connection, 'STDOUT', $tx->{fcgi_id}, undef);
-    $self->write_records($connection, 'END_REQUEST', $tx->{fcgi_id},
+    return
+      unless $self->write_records($connection, 'STDOUT', $tx->{fcgi_id},
+        undef);
+    return
+      unless $self->write_records($connection, 'END_REQUEST', $tx->{fcgi_id},
         pack('CCCCCCCC', 0));
 }
 
@@ -313,7 +328,11 @@ sub _read_chunk {
     while (length $chunk < $length) {
 
         # We don't wait forever
-        return undef unless IO::Select->new($connection)->can_read(1);
+        my $poll = IO::Poll->new;
+        $poll->mask($connection, POLLIN);
+        $poll->poll(1);
+        my @readers = $poll->handles(POLLIN);
+        return unless @readers;
 
         # Slurp
         $connection->sysread(my $buffer, $length - length $chunk, 0);
