@@ -75,38 +75,34 @@ sub compile {
 
     # Shortcut
     my $code = $self->code;
-    return undef unless $code;
-
-    # Catch compilation warnings
-    local $SIG{__WARN__} = sub { };
+    return unless $code;
 
     # Compile
     my $compiled = eval $code;
-    die $self->_error($@) if $@;
+
+    # Exception
+    return Mojo::Template::Exception->new($@, $self->template) if $@;
 
     $self->compiled($compiled);
-    return $self;
+    return;
 }
 
 sub interpret {
-    my $self   = shift;
-    my $output = shift;
+    my $self = shift;
 
     # Shortcut
     my $compiled = $self->compiled;
-    return undef unless $compiled;
+    return unless $compiled;
 
-    # Catch interpreter warnings
-    local $SIG{__WARN__} = sub { };
+    # Catch errors
+    local $SIG{__DIE__} =
+      sub { die Mojo::Template::Exception->new(shift, $self->template) };
 
     # Interpret
-    $$output = eval { $compiled->(@_) };
-    if ($@) {
-        $$output = $self->_error($@);
-        return 0;
-    }
+    my $output = eval { $compiled->(@_) };
+    $output = $@ if $@;
 
-    return 1;
+    return $output;
 }
 
 # I am so smart! I am so smart! S-M-R-T! I mean S-M-A-R-T...
@@ -238,7 +234,8 @@ sub render {
     $self->build;
 
     # Compile
-    $self->compile;
+    my $e = $self->compile;
+    return $e if $e;
 
     # Interpret
     return $self->interpret(@_);
@@ -271,8 +268,10 @@ sub render_file_to_file {
     my $tpath = shift;
 
     # Render
-    my $output;
-    return 0 unless $self->render_file($spath, \$output, @_);
+    my $output = $self->render_file($spath, @_);
+
+    # Exception
+    return $output if ref $output;
 
     # Write to file
     return $self->_write_file($tpath, $output);
@@ -284,31 +283,15 @@ sub render_to_file {
     my $path = shift;
 
     # Render
-    my $output;
-    return 0 unless $self->render($tmpl, \$output, @_);
+    my $output = $self->render($tmpl, @_);
+
+    # Exception
+    return $output if ref $output;
 
     # Write to file
     return $self->_write_file($path, $output);
 }
 
-# Debug goodness
-sub _error {
-    my ($self, $error) = @_;
-
-    my $te = Mojo::Template::Exception->new(message => $error);
-
-    # Line
-    if ($error =~ /at\s+\(eval\s+\d+\)\s+line\s+(\d+)/) {
-
-        my $line = $1;
-        my @lines = split /\n/, $self->template;
-
-        $te->parse_context(\@lines, $line);
-    }
-
-    return $te;
-}
-
 sub _write_file {
     my ($self, $path, $output) = @_;
 
@@ -322,7 +305,7 @@ sub _write_file {
     # Write to file
     $file->syswrite($output) or croak "Can't write to file '$path': $!";
 
-    return 1;
+    return 0;
 }
 
 1;
@@ -338,8 +321,7 @@ Mojo::Template - Perlish Templates!
     my $mt = Mojo::Template->new;
 
     # Simple
-    my $output;
-    $mt->render(<<'EOF', \$output);
+    my $output = $mt->render(<<'EOF');
     <html>
       <head></head>
       <body>
@@ -350,8 +332,7 @@ Mojo::Template - Perlish Templates!
     print $output;
 
     # More complicated
-    my $output;
-    $mt->render(<<'EOF', \$output, 23, 'foo bar');
+    my $output = $mt->render(<<'EOF', 23, 'foo bar');
     %= 5 * 5
     % my ($number, $text) = @_;
     test 123
@@ -369,7 +350,6 @@ designed specifically for all those small tasks that come up during big
 projects.
 Like preprocessing a config file, generating text from heredocs and stuff
 like that.
-For bigger tasks you might want to use L<HTML::Mason> or L<Template>.
 
     <% Inline Perl %>
     <%= Perl expression, replaced with result %>
@@ -394,7 +374,7 @@ them if necessary.
     $mt->tag_start('[@@');
     $mt->tag_end('@@]');
     $mt->expression_mark('&');
-    $mt->render(<<'EOF', \$output, 23);
+    my $output = $mt->render(<<'EOF', 23);
     @@ my $i = shift;
     <% no code just text [@@& $i @@]
     EOF
@@ -418,14 +398,12 @@ tricky.
 But L<Mojo::Template> will return L<Mojo::Template::Exception> objects that
 stringify to error messages with context.
 
-    Template error around line 4.
-    -----------------------------------------------------------------
+    Error around line 4.
     2: </head>
     3: <body>
     4: % my $i = 2; xx
     5: %= $i * 2
     6: </body>
-    -----------------------------------------------------------------
     Bareword "xx" not allowed while "strict subs" in use at (eval 13)
     line 4.
 
@@ -442,11 +420,12 @@ build a wrapper around it.
     $mt->template($template);
     $mt->code($code);
     $mt->compile;
-    my $output;
-    $mt->interpret(\$output, @arguments);
+    my $output = $mt->interpret(@arguments);
 
 =head1 ATTRIBUTES
 
+L<Mojo::Template> implements the following attributes.
+
 =head2 C<code>
 
     my $code = $mt->code;
@@ -507,12 +486,12 @@ following new ones.
 
 =head2 C<compile>
 
-    $mt = $mt->compile;
+    my $exception = $mt->compile;
 
 =head2 C<interpret>
 
-    my $success = $mt->interpret;
-    my $success = $mt->interpret(\$output, @arguments);
+    my $output = $mt->interpret;
+    my $output = $mt->interpret(@arguments);
 
 =head2 C<parse>
 
@@ -520,25 +499,25 @@ following new ones.
 
 =head2 C<render>
 
-    my $success = $mt->render($template);
-    my $success = $mt->render($template, \$output, @arguments);
+    my $output = $mt->render($template);
+    my $output = $mt->render($template, @arguments);
 
 =head2 C<render_file>
 
-    my $success = $mt->render_file($template_file);
-    my $success = $mt->render_file($template_file, \$result, @arguments);
+    my $output = $mt->render_file($template_file);
+    my $output = $mt->render_file($template_file, @arguments);
 
 =head2 C<render_file_to_file>
 
-    my $success = $mt->render_file_to_file($template_file, $output_file);
-    my $success = $mt->render_file_to_file(
+    my $exception = $mt->render_file_to_file($template_file, $output_file);
+    my $exception = $mt->render_file_to_file(
         $template_file, $output_file, @arguments
     );
 
 =head2 C<render_to_file>
 
-    my $success = $mt->render_to_file($template, $output_file);
-    my $success = $mt->render_to_file(
+    my $exception = $mt->render_to_file($template, $output_file);
+    my $exception = $mt->render_to_file(
         $template, $output_file, @arguments
     );
 
