@@ -213,13 +213,13 @@ sub _find_executable {
     for (1 .. 5) {
         push @uplevel, '..';
 
-        # executable in bin directory
-        $path = File::Spec->catfile(@base, @uplevel, 'bin', $name);
+        # App executable in script directory
+        $path = File::Spec->catfile(@base, @uplevel, 'script', $name);
         last if -f $path;
 
-        # "mojo" in bin directory
+        # Custom executable in script directory
         $path =
-          File::Spec->catfile(@base, @uplevel, 'bin', $self->executable);
+          File::Spec->catfile(@base, @uplevel, 'script', $self->executable);
         last if -f $path;
     }
 
@@ -227,7 +227,7 @@ sub _find_executable {
     return $path if -f $path;
 
     # Not found
-    return undef;
+    return;
 }
 
 sub _generate_port {
@@ -302,6 +302,8 @@ L<Mojo::Test::Server> is a test harness for server tests.
 
 =head1 ATTRIBUTES
 
+L<Mojo::Test::Server> implements the following attribute.
+
 =head2 C<command>
 
     my $command = $server->command;
